@@ -1,7 +1,7 @@
 /* buf.c: scratch-file buffer routines for the ed line editor. */
 /*  GNU ed - The GNU line editor.
     Copyright (C) 1993, 1994 Andrew Moore, Talke Studio
-    Copyright (C) 2006, 2007 Antonio Diaz Diaz.
+    Copyright (C) 2006, 2007, 2008 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ int inc_addr( int addr )
   { if( ++addr > _last_addr ) addr = 0; return addr; }
 
 int dec_addr( int addr )
-  { if( --addr < 0 ) addr = _last_addr - 1; return addr; }
+  { if( --addr < 0 ) addr = _last_addr; return addr; }
 
 
 /* link next and previous nodes */
