@@ -1,11 +1,11 @@
 /* signal.c: signal and miscellaneous routines for the ed line editor. */
 /*  GNU ed - The GNU line editor.
     Copyright (C) 1993, 1994 Andrew Moore, Talke Studio
-    Copyright (C) 2006, 2007 Antonio Diaz Diaz.
+    Copyright (C) 2006, 2007, 2008 Antonio Diaz Diaz.
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <ctype.h>
@@ -45,23 +44,25 @@ void sighup_handler( int signum )
   else
     {
     char hb[] = "ed.hup";
-    char *hup = 0;             /* hup filename */
-    char *s;
-    int n, m = 0;
-
     sighup_pending = 0;
-    if( last_addr() && write_file( "ed.hup", "w", 1, last_addr(), 1 ) < 0 &&
-        ( s = getenv( "HOME" ) ) != 0 &&
-        ( !( n = strlen( s ) ) ||
-          ( int )( n + ( m = *( s + n - 1 ) != '/' ) + sizeof( hb ) ) < path_max( 0 ) ) &&
-        ( hup = ( char *) malloc( n + m + sizeof( hb ) ) ) != 0 )
+    if( last_addr() && modified() &&
+        write_file( hb, "w", 1, last_addr() ) < 0 )
       {
-      memcpy( hup, s, n );
-      memcpy( hup + n, m ? "/" : "", 1 );
-      memcpy( hup + n + m, hb, sizeof( hb ) );
-      write_file( hup, "w", 1, last_addr(), 1 );
+      char *s = getenv( "HOME" );
+      int n = ( s ? strlen( s ) : 0 );
+      int m = ( ( !n || *( s + n - 1 ) != '/' ) ? 1 : 0 );
+      char *hup = ( ( n + m + (int)sizeof( hb ) < path_max( 0 ) ) ?
+                    ( char *) malloc( n + m + sizeof( hb ) ) : 0 );
+      if( n && hup )		/* hup filename */
+        {
+        memcpy( hup, s, n );
+        if( m ) memcpy( hup + n, "/", 1 );
+        memcpy( hup + n + m, hb, sizeof( hb ) );
+        if( write_file( hup, "w", 1, last_addr() ) >= 0 ) exit( 0 );
+        }
+      exit( 1 );		/* hup file write failed */
       }
-    exit( 2 );
+    exit( 0 );
     }
   }
 
@@ -83,7 +84,6 @@ void sigint_handler( int signum )
 
 void sigwinch_handler( int signum )
   {
-  signum = 0;			/* keep compiler happy */
 #ifdef TIOCGWINSZ
   struct winsize ws;            /* window size structure */
 
@@ -94,6 +94,7 @@ void sigwinch_handler( int signum )
     if( ws.ws_col > 8 && ws.ws_col < 1800 ) _window_columns = ws.ws_col - 8;
     }
 #endif
+  signum = 0;			/* keep compiler happy */
   }
 
 
@@ -103,7 +104,11 @@ int set_signal( int signum, void (*handler )( int ) )
 
   new_action.sa_handler = handler;
   sigemptyset( &new_action.sa_mask );
+#ifdef SA_RESTART
   new_action.sa_flags = SA_RESTART;
+#else
+  new_action.sa_flags = 0;
+#endif
   return sigaction( signum, &new_action, 0 );
   }
 
